@@ -106,13 +106,11 @@ estimatetransprobs <- function(dynamicvariables, pairdata,
   dynvar0 <- act$dynamicvariables0
   dynvar1 <- act$dynamicvariables1
   statespace <- act$statespace
-  pairdata <- pairdata[c(dynvar1, dynvar0, factors, by)]
-
 
   if(!is.null(pairdata)) {
-    requirednames <- c(factors, by)
+    requirednames <- c(dynvar0, dynvar1, factors, by)
     missingnames <- setdiff(requirednames, names(pairdata))
-    if(length(missingnames) > 0) stop(paste0("Variable '", list(missingnames), "' not present in pairdata."))
+    if(length(missingnames) > 0) stop(paste0("Variable(s) '", list(missingnames), "' not present in pairdata."))
 
     # Check pairdata against statespace
     a <- act$statespace0
@@ -125,9 +123,14 @@ estimatetransprobs <- function(dynamicvariables, pairdata,
     a$check_missing_combinations <- 1
     a <- merge(pairdata, a, by.x = c(factors, by, act$dynamicvariables1),
                by.y = c(factors, by, gsub("1$", "", act$dynamicvariables1)), all.x=TRUE)
-    if(anyNA(a$check_missing_combinations)) stop("Pairdata has transitions resulting in states that are not in statespace.")
+    if(anyNA(a$check_missing_combinations)) {
+      print("Pairdata has transitions resulting in states that are not in statespace.")
+      print(utils::head(a[is.na(a$check_missing_combinations),,drop=FALSE]))
+      stop("Pairdata has transitions resulting in states that are not in statespace.")
+    }
   }
 
+  pairdata <- pairdata[c(dynvar1, dynvar0, factors, by)]
   processed_rows <- 0
 
   A <- do.call(rbind, lapply(statespace, function(statespacepart) {
